package sgc.portal.base.persistence;

import sgc.portal.base.model.ComData;
import sgc.portal.base.model.FileAll;
import sgc.portal.base.util.EasyHashMap;
//import kr.co.sgc.com.cmm.model.SlpSearch;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 프로그램 목록 매퍼  DAO
 *
 * @author mir(khjang@sgc.co.kr)
 * @version 1.0.0
 * @since  2020. 8. 2.
 */


@Mapper
public interface ComSearchMapper {
    //사용자별프로그램 권한정보 조회
    EasyHashMap<String, Object> selectPrgAuth(ComData comdatas);

    //지급공제항목
    List<EasyHashMap<String, Object>> selectPymtdedc(ComData comdatas);

    //일반직 업적평가Pool 조회
    List<EasyHashMap<String, Object>> selectAcvmPool(ComData comdatas);

    //상벌공통코드 조회
    List<EasyHashMap<String, Object>> selectRewaPR(ComData comdatas);

    //공통코드 조회(대분류코드와 설정코드1의 조건으로 공통코드 조회)
    List<EasyHashMap<String, Object>> selectComDtl(ComData comdatas);

    //공통코드 조회(대분류코드와 설정코드2의 조건으로 공통코드 조회)
    List<EasyHashMap<String, Object>> selectComDtl2(ComData comdatas);

    //공통코드 조회(대분류코드와 설정코드4의 조건으로 공통코드 조회)
    List<EasyHashMap<String, Object>> selectComDtl4(ComData comdatas);

    //증빙코드정보 조회( 2020-04-12 mir)
    List<EasyHashMap<String, Object>> selectComEvdc(ComData comdatas);

    //업무 취급 권한 정보 조회( 2020-07-02 blue3819)
    List<EasyHashMap<String, Object>> selectHdlgAuth(ComData comdatas);

    //은행정보 조회( 2020-07-02 mir)
    List<EasyHashMap<String, Object>> selectComBank(ComData comdatas);

    //은행계좌정보 조회( 2020-07-02 mir)
    List<EasyHashMap<String, Object>> selectComAcct(ComData comdatas);

    //사업장 코드 조회( 2020-08-28 ax5656)
    List<EasyHashMap<String, Object>> selectComMapBsuCd(ComData comdatas);

    //전표 조회( 2020-11-20 saiqud)
//    List<EasyHashMap<String, Object>> selectSlpList(SlpSearch slpSearch);

    //사업운영의 집행예산코드 대분류 조회(2019-07-22 Mir)
    List<EasyHashMap<String, Object>> selectBaLaclCd(ComData comdatas);

    //사업운영의 집행예산코드 중분류 조회(2019-07-22 Mir)
    List<EasyHashMap<String, Object>> selectBaMdclCd(ComData comdatas);

    //표준집행예산코드 조회 (2019-07-30 Mir)
    List<EasyHashMap<String, Object>> selectBaComExtoStd(ComData comdatas);

    List<FileAll> selectAllFileList(FileAll fileAll);
}

